#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""
Tests for conveyor.conveyor module
"""
import argparse
import logging
import sys
from unittest.mock import MagicMock, patch

import conveyor.conveyor as con

logger = logging.getLogger("test_conveyer")
logger.setLevel(logging.INFO)
logger.addHandler(logging.StreamHandler(sys.stdout))

expected_settings = {
    "qa_delivery_area": "/lustre/aoc/cluster/pipeline/docker/workspaces/qa2",
    "weblog_cache_area": "/lustre/aoc/cluster/pipeline/docker/workspaces/cache/weblog",
    "workspaces_lustre_root_dir": "/lustre/aoc/cluster/pipeline/docker/workspaces/spool",
    "current_root_directory": "current/directory",
    "current_subdirectory": "dir_123",
    "destination_dir": "/lustre/aoc/cluster/pipeline/docker/workspaces/spool/tmpabcd1234",
    "destination_subdir": "tmpabcd1234",
    "system_id": 2,
    "sdm_ids": "brain_000.58099.67095825232",
}

args = argparse.Namespace(deliver=None, retrieve=None, deliver_img=None, retrieve_img=None, qa_fail=None)

TEST_JSON = "test/test.json"


class TestConveyor:
    def test_get_settings(self):
        with patch("pathlib.Path.cwd") as cwd:
            settings = con._get_settings(TEST_JSON)
            assert settings["qa_delivery_area"] == expected_settings["qa_delivery_area"]
            assert settings["weblog_cache_area"] == expected_settings["weblog_cache_area"]
            assert settings["workspaces_lustre_root_dir"] == expected_settings["workspaces_lustre_root_dir"]
            # mock calls to cwd and count
            assert cwd.call_count == 2
            assert settings["destination_dir"] == expected_settings["destination_dir"]
            assert settings["destination_subdir"] == expected_settings["destination_subdir"]
            assert settings["system_id"] == expected_settings["system_id"]
            assert settings["sdm_ids"] == expected_settings["sdm_ids"]

    def test_main_deliver(self):
        args.deliver = [TEST_JSON]

        with patch("argparse.ArgumentParser.parse_args", MagicMock(return_value=args)):
            assert args.deliver[0] == TEST_JSON
            with patch("conveyor.deliver.DeliveryConveyor.convey") as del_convey:
                con.main()
                assert del_convey.call_count == 1

        # reset for other testing
        args.deliver = None

    def test_main_retrieve(self):
        args.retrieve = [TEST_JSON]

        with patch("argparse.ArgumentParser.parse_args", MagicMock(return_value=args)):
            with patch("conveyor.retrieve.RetrievalConveyor.convey") as ret_convey:
                con.main()
                assert ret_convey.call_count == 1

        # reset for other testing
        args.retrieve = None

    def test_main_qa_fail(self):
        """
        Test the QA Fail REST endpoint

        :return:
        """
        args.qa_fail = [TEST_JSON]
        with patch("os.chdir"):
            with patch("argparse.ArgumentParser.parse_args", MagicMock(return_value=args)):
                with patch("conveyor.retrieve.RetrievalConveyor.convey") as mock_convey:
                    con.main()
                    assert mock_convey.call_count == 1

        # reset for other testing
        args.qa_fail = None
