/*
 * Copyright 2021 Associated Universities, Inc.
 *
 * This file is part of Telescope Time Allocation Tools (TTAT).
 *
 * TTAT is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * TTAT is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with TTAT.  If not, see <https://www.gnu.org/licenses/>.
 *
 */
import {ComponentFixture, fakeAsync, TestBed} from '@angular/core/testing';
import {RouterTestingModule} from "@angular/router/testing";
import {AlertComponent} from './alert.component';
import {AlertService} from "../shared/alert/alert.service";
import {of} from "rxjs";
import {BrowserAnimationsModule} from "@angular/platform-browser/animations";
import {By} from "@angular/platform-browser";
import {CUSTOM_ELEMENTS_SCHEMA} from "@angular/core";

describe('AlertComponent', () => {
  let alertService: AlertService;
  let component: AlertComponent;
  let fixture: ComponentFixture<AlertComponent>;

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      imports: [RouterTestingModule, BrowserAnimationsModule],
      providers: [AlertService],
      declarations: [ AlertComponent ],
      schemas: [CUSTOM_ELEMENTS_SCHEMA]
    })
    .compileComponents();
  });

  beforeEach(() => {
    alertService = TestBed.inject(AlertService);
    fixture = TestBed.createComponent(AlertComponent);
    component = fixture.componentInstance;
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  it('should receive and display messages from the service', fakeAsync(() => {
    const message = {type: 'success', text: 'success message'};
    spyOn(alertService, 'getMessage').and.returnValue(of(message));
    fixture.detectChanges();
    expect(component.message).toEqual(message);
    let banner = fixture.debugElement.query(By.css('#global-alert')).nativeElement;
    expect(banner).toBeTruthy();
    expect(banner.textContent).toContain(message.text);
  }));

  it('should clear message on button click', fakeAsync(() => {
    const message = {type: 'success', text: 'success message'};
    spyOn(alertService, 'getMessage').and.returnValue(of(message));
    fixture.detectChanges();
    expect(component.message).toEqual(message);
    let bannerBtn = fixture.debugElement.query(By.css('button')).nativeElement;
    bannerBtn.click();
    fixture.detectChanges();
    expect(component.message).toBeNull();
    let banner = fixture.debugElement.query(By.css('#global-alert'));
    expect(banner).toBeNull();
  }));
});
