/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import {APP_INITIALIZER, NgModule} from '@angular/core';
import {BrowserModule} from '@angular/platform-browser';

import {AppRoutingModule} from './app-routing.module';
import {AppComponent} from './app.component';
import {NgbModule} from '@ng-bootstrap/ng-bootstrap';
import {FontAwesomeModule} from '@fortawesome/angular-fontawesome';
import {JobsListComponent} from './jobs-list/jobs-list.component';
import {JobItemComponent} from './jobs-list/job-item/job-item.component';
import {SettingsPageComponent} from './settings-page/settings-page.component';
import {GlobalSettingsComponent} from './settings-page/global-settings/global-settings.component';
import {HeaderComponent} from "./header/header.component";
import {FooterComponent} from "./footer/footer.component";
import {AlertComponent} from "./alert/alert.component";
import {UsersListComponent} from "./users-list/users-list.component";
import {TestDataService} from "./services/test-data.service";
import {UserItemComponent} from "./users-list/user-item/user-item.component";

export function initializeApp(testDataService: TestDataService) {
  return (): Promise<any> => { return testDataService.Init(); }
}

@NgModule({
  declarations: [
    AppComponent,
    JobsListComponent,
    JobItemComponent,
    SettingsPageComponent,
    GlobalSettingsComponent,
    HeaderComponent,
    FooterComponent,
    AlertComponent,
    UsersListComponent,
    UserItemComponent,
  ],
  imports: [
    BrowserModule,
    AppRoutingModule,
    NgbModule,
    FontAwesomeModule
  ],
  providers: [
    {provide: APP_INITIALIZER, useFactory: initializeApp, deps: [TestDataService], multi: true},
  ],
  bootstrap: [AppComponent]
})
export class AppModule { }
