#!/bin/bash
#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.

# Set failfast
set -e
set -o pipefail

# Install Python 3.8
PYTHON_VERSION=3.8.7
yum install -y gcc
yum install -y openssl-devel
yum install -y bzip2-devel
yum install -y libffi-devel

cd /opt
wget https://www.python.org/ftp/python/$PYTHON_VERSION/Python-$PYTHON_VERSION.tgz
tar xzf Python-$PYTHON_VERSION.tgz && cd Python-$PYTHON_VERSION
./configure --enable-optimizations
make altinstall
cd ..
rm -rf Python-$PYTHON_VERSION.tgz
yum clean all
rm -rf /var/cache/yum

# Add Python install location to the path
export LD_LIBRARY_PATH="$LD_LIBRARY_PATH:/opt/Python-3.8.7/"

# Make symbolic link of python3 install to where it's installed on dev
mkdir -p /home/ssa/bin
ln -s "$(which python3.8)" /home/ssa/bin/python3.8

export PATH="${PATH}:/home/ssa/bin"
